# -*- coding: utf-8 -*-

"""!
For Maya2022 - Make Rig ICONS for Character Size
             - This is for Python3  V2.0
@file
@author Ritaro

"""

import maya.cmds as cmds
import maya.mel as mel

def set_new_size(o_size):
    if cmds.checkBoxGrp('immediate_on_off',q=True,value1=True) == 1:
        if cmds.ls( sl=True ):
            first_selected = cmds.ls(sl=True)[0]
            try:
                cmds.xform(first_selected, scale=(o_size, o_size, o_size) )
            except:
                print('Not Sizeable')

def merge_curves_shapes(*agrs):
    try:
        if not cmds.ls( sl=True ):
            print('Nothing is selected')
        else:
            s_obj = cmds.ls(selection=True)
            cmds.makeIdentity(apply=True, translate= 1, rotate= 1, scale= 1, normal= 0)
            cmds.delete(constructionHistory=True)
            s_obj_shape = cmds.listRelatives(s_obj, shapes=True)
            for i in range(len(s_obj_shape)-1):
                cmds.parent(s_obj_shape[i],s_obj[-1],add = 1, shape = 1)
                cmds.delete(s_obj[i])
                cmds.select(s_obj[-1], replace = 1)
    except:
        print('Nothing to merge')

def center_pivot(*agrs):
    if not cmds.ls( sl=True ):
        print('Nothing is selected')
    else:
        cmds.xform(centerPivots=True)

def freeze_str(*agrs):
    if not cmds.ls( sl=True ):
        print('Nothing to Freeze')
    else:
        cmds.makeIdentity( apply=True )


def unlock_attribues():
    m_obj = cmds.ls(selection = 1)
    for i in range(len(m_obj)):
        cmds.setAttr(m_obj[i] + ".tx", keyable = 1, lock = 0)
        cmds.setAttr(m_obj[i] + ".ty", keyable = 1, lock = 0)
        cmds.setAttr(m_obj[i] + ".tz", keyable = 1, lock = 0)
        
        cmds.setAttr(m_obj[i] + ".rx", keyable = 1, lock = 0)
        cmds.setAttr(m_obj[i] + ".ry", keyable = 1, lock = 0)
        cmds.setAttr(m_obj[i] + ".rz", keyable = 1, lock = 0)
        
        cmds.setAttr(m_obj[i] + ".sx", keyable = 1, lock = 0)
        cmds.setAttr(m_obj[i] + ".sy", keyable = 1, lock = 0)
        cmds.setAttr(m_obj[i] + ".sz", keyable = 1, lock = 0)

def mirror_x(*args):
    if not cmds.ls( sl=True ):
        print('Nothing is selected')
    else:
        unlock_attribues()
        mirrorGrpX = cmds.group()
        cmds.xform(objectSpace = 1,  pivots = (0, 0, 0), scale = (-1, 1, 1))
        cmds.ungroup(mirrorGrpX)
        cmds.makeIdentity(apply = 1, translate = 1, rotate = 1, scale = 1, normal = 0)

def mirror_y(*args):
    if not cmds.ls( sl=True ):
        print('Nothing is selected')
    else:
        unlock_attribues()
        mirrorGrpY = cmds.group()
        cmds.xform(objectSpace = 1,  pivots = (0, 0, 0), scale = (1, -1, 1))
        cmds.ungroup(mirrorGrpY)
        cmds.makeIdentity(apply = 1, translate = 1, rotate = 1, scale = 1, normal = 0)

def mirror_z(*args):
    if not cmds.ls( sl=True ):
        print('Nothing is selected')
    else:
        unlock_attribues()
        mirrorGrpZ = cmds.group()
        cmds.xform(objectSpace = 1,  pivots = (0, 0, 0), scale = (1, 1, -1))
        cmds.ungroup(mirrorGrpZ)
        cmds.makeIdentity(apply = 1, translate = 1, rotate = 1, scale = 1, normal = 0)

def rotate_x(*args):
    if not cmds.ls( sl=True ):
        print('Nothing is selected')
    else:
        cmds.rotate(90,0,0,relative=True, objectSpace=True, )

def rotate_y(*args):
    if not cmds.ls( sl=True ):
        print('Nothing is selected')
    else:
        cmds.rotate(0,90,0,relative=True, objectSpace=True, )

def rotate_z(*args):
    if not cmds.ls( sl=True ):
        print('Nothing is selected')
    else:
        cmds.rotate(0,0,90,relative=True, objectSpace=True, )


def icon_color_index(value):
    set_color_index = value + 1
    cmds.colorIndexSliderGrp('icon_color', edit=True,value=set_color_index).encode('utf-8')
    if cmds.ls( sl=True ):
        o_selected = cmds.ls(selection = True,objectsOnly=True )[0]
        cmds.setAttr(o_selected + ".overrideEnabled", 1)
        cmds.setAttr(o_selected + ".overrideColor", value) 

def set_icon_color_selected(*args):
    if not cmds.ls( sl=True ):
        print('Nothing is selected')
    else:
        first_selected = cmds.ls(sl=True)[0]
        selected_object = cmds.ls(sl=True)
        set_h_color_index =cmds.colorIndexSliderGrp('icon_color', q=True,value=True) - 1
        for node in selected_object:
            cmds.setAttr(node + ".overrideEnabled", 1)
            cmds.setAttr(node + ".overrideColor", set_h_color_index )
        cmds.select( clear=True )
        cmds.select( first_selected, replace=True )


def ri_rig_icons_menu(*args):

    if cmds.window('ri_rig_icons', exists=True):
        cmds.deleteUI('ri_rig_icons')

    cmds.window()
    window = cmds.window('ri_rig_icons', title='ri Rig ICONs V2.0',sizeable=False, topLeftCorner=[200, 200], widthHeight=(410,300))
    top_w = cmds.columnLayout('  set size  ',width=400,height=50,adjustableColumn=False)
    cmds.rowColumnLayout(numberOfColumns=4)
    cmds.intSliderGrp('set_size', field=True, label='Set ICON Size ',
        columnWidth3=[85,40,120], minValue=1, maxValue=50, fieldMinValue=1, fieldMaxValue=50, value=1,dragCommand=lambda x:set_new_size(int(x)))
    cmds.checkBoxGrp('immediate_on_off',columnWidth2=[57,10], numberOfCheckBoxes=1, label='Immediate', value1=False)
    cmds.button(label=' Freeze SRT ',bgc=[0.3,0.3,0.3],command=freeze_str)
    cmds.setParent('..')
    cmds.separator( height=5, style='singleDash' )
    cmds.setParent('..')
    tabs = cmds.tabLayout(innerMarginWidth=5,innerMarginHeight=5)

    tab_cl1 = cmds.columnLayout('  20  ',width=400,height=240,adjustableColumn=False)

    cmds.text(label='2D Flat ICONs',width=410,bgc=[0.2,0.2,0.2],align='center' )
    cmds.scrollLayout(childResizable = 1)
    cmds.rowColumnLayout(numberOfColumns=4)
    cmds.button('Triangle',label='Triangle',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Ue Sankaku',command=lambda *args: select_icon('Triangle'))
    cmds.button('Square',label='Square',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Shikaku',command=lambda *args: select_icon('Square'))
    cmds.button('Hexagon',label='Hexagon',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Rokkaku',command=lambda *args: select_icon('Hexagon'))
    cmds.button('Circle',label='Circle',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='En',command=lambda *args: select_icon('Circle'))
    cmds.button('CrossCircle',label='CrossCircle',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Jyuji En',command=lambda *args: select_icon('CrossCircle'))
    cmds.button('Cross',label='Cross',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Jyuji',command=lambda *args: select_icon('Cross'))
    cmds.button('Cross2',label='Cross2',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Jyuji2',command=lambda *args: select_icon('Cross2'))
    cmds.button('FlatCross',label='FlatCross',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Jyuji2',command=lambda *args: select_icon('FlatCross'))
    cmds.button('Angle',label='Angle',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Kado',command=lambda *args: select_icon('Angle'))
    cmds.button('PoleSquare',label='PoleSquare',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Bou Shikaku',command=lambda *args: select_icon('PoleSquare'))
    cmds.button('PoleCircle',label='PoleCircle',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Bou En',command=lambda *args: select_icon('PoleCircle'))
    cmds.button('Star',label='Star',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Hoshi',command=lambda *args: select_icon('Star'))
    cmds.button('Circle180',label='Circle180',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='En 180 do',command=lambda *args:select_icon('Circle180'))
    cmds.button('Circle270',label='Circle270',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='En 270 do',command=lambda *args:select_icon('Circle270'))
    cmds.button('Dumbell',label='Dumbell',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Danmel',command=lambda *args:select_icon('Dumbell'))

    cmds.setParent('..')
    cmds.setParent('..')
    cmds.setParent('..')


    tab_cl2 = cmds.columnLayout('  3D  ',width=400,height=150,adjustableColumn=False)

    cmds.text(label='3D Prisms ICONs',width=400,bgc=[0.2,0.2,0.2],align='center' )
    cmds.scrollLayout(childResizable = 1)
    cmds.rowColumnLayout(numberOfColumns=4)
    cmds.button('Piramid',label='Piramid',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Sankakucyu',command=lambda *args:select_icon('Piramid'))
    cmds.button('Piramid2',label='Piramid2',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Sankakucyu2',command=lambda *args:select_icon('Piramid2'))
    cmds.button('Cube',label='Cube',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Rippoutai',command=lambda *args:select_icon('Cube'))
    cmds.button('Hexagonal',label='Hexagonal',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Rokkakucyu',command=lambda *args:select_icon('Hexagonal'))
    cmds.button('Sphere',label='Sphere',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Kyu',command=lambda *args:select_icon('Sphere'))
    cmds.button('HalfSphere',label='HalfSphere',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='HanKyu',command=lambda *args:select_icon('HalfSphere'))
    cmds.button('Octahedron',label='Octahedron',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='SeiHachimentai',command=lambda *args:select_icon('Octahedron'))
    cmds.button('Null',label='Null',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Null',command=lambda *args:select_icon('Null'))
    cmds.button('Jack',label='Jack',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Jack',command=lambda *args:select_icon('Jack'))
    cmds.button('Triangles',label='Triangles',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='jyuuji Sankaku',command=lambda *args:select_icon('Triangles'))

    cmds.setParent('..')
    cmds.setParent('..')
    cmds.setParent('..')

    tab_cl3 = cmds.columnLayout('Arrows',width=400,height=200,adjustableColumn=False)

    cmds.text(label='Arrow ICONs',width=400,bgc=[0.2,0.2,0.2],align='center' )
    cmds.scrollLayout(childResizable = 1)
    cmds.rowColumnLayout(numberOfColumns=4)
    cmds.button('LineArrow',label='LineArrow',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Yajirushi Sen',command=lambda *args:select_icon('LineArrow'))
    cmds.button('Arrow',label='Arrow',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Yajirushi',command=lambda *args:select_icon('Arrow'))
    cmds.button('LineArrows2',label='LineArrows2',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Yajirushi Sen2',command=lambda *args:select_icon('LineArrows2'))
    cmds.button('Arrows2',label='Arrows2',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Yajirushi2',command=lambda *args:select_icon('Arrows2'))
    cmds.button('LineArrows4',label='LineArrows4',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Yajirushi Sen4',command=lambda *args:select_icon('LineArrows4'))
    cmds.button('Arrows4',label='Arrows4',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Yajirushi4',command=lambda *args:select_icon('Arrows4'))
    cmds.button('Arrows4s',label='Arrows4s',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Yajirushi4s',command=lambda *args:select_icon('Arrows4s'))
    cmds.button('Arrows8s',label='Arrows8s',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Yajirushi8',command=lambda *args:select_icon('Arrows8s'))
    cmds.button('RoundArrows',label='RoundArrows',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='kyuYajirushi',command=lambda *args:select_icon('RoundArrows'))
    cmds.button('RoundArrows2',label='RoundArrows2',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='kyuYajirushi2',command=lambda *args:select_icon('RoundArrows2'))
    cmds.button('Line90Arrow',label='Line90Arrow',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Yajirushi 90 Sen',command=lambda *args:select_icon('Line90Arrow'))
    cmds.button('90Arrow',label='90Arrow',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Yajirushi 90',command=lambda *args:select_icon('90Arrow'))
    cmds.button('Line180Arrows',label='Line180Arrows',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Yajirushi 180 Sen',command=lambda *args:select_icon('Line180Arrows'))
    cmds.button('180Arrows',label='180Arrows',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Yajirushi 180',command=lambda *args:select_icon('180Arrows'))
    cmds.button('Line360Arrow',label='Line360Arrow',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Yajirushi 360 Sen',command=lambda *args:select_icon('Line360Arrow'))
    cmds.button('OverArrows',label='OverArrows',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Ue Yajirushi',command=lambda *args:select_icon('OverArrows'))
    cmds.button('BothArrows',label='BothArrows',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Ryo Yajirushi',command=lambda *args:select_icon('BothArrows'))
    cmds.button('ArrowDown',label='ArrowDown',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Shita Yajirushi',command=lambda *args:select_icon('ArrowDown'))
    cmds.button('ArrowDown2',label='ArrowDown2',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Shita Yajirushi2',command=lambda *args:select_icon('ArrowDown2'))
    cmds.button('ArrowDown3',label='ArrowDown3',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Shita Yajirushi3',command=lambda *args:select_icon('ArrowDown3'))
    cmds.button('ArrowDown4',label='ArrowDown4',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Shita Yajirushi4',command=lambda *args:select_icon('ArrowDown4'))
    cmds.button('ArrowDown5',label='ArrowDown5',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Shita Yajirushi5',command=lambda *args:select_icon('ArrowDown5'))
    cmds.button('4SideArrows',label='4SideArrows',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Shihou Yajirushi',command=lambda *args:select_icon('4SideArrows'))
    cmds.button('4SideArrows2',label='4SideArrows2',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Shihou Yajirushi2',command=lambda *args:select_icon('4SideArrows2'))

    cmds.setParent('..')
    cmds.setParent('..')
    cmds.setParent('..')

    tab_cl4 = cmds.columnLayout('Others',width=400,height=150,adjustableColumn=False)

    cmds.text(label='Other ICONs',width=400,bgc=[0.2,0.2,0.2],align='center' )
    cmds.scrollLayout(childResizable = 1)
    cmds.rowColumnLayout(numberOfColumns=4)
    cmds.button('CenterArrows',label='CenterArrows',height=35,width=100,bgc=[0.3,0.3,0.3],
        annotation='Cyuushin Yajirushi',command=lambda *args:select_icon('CenterArrows'))
    cmds.button('Hand',label='Hand',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Te',command=lambda *args:select_icon('Hand'))
    cmds.button('Foot',label='Foot',height=35,width=100,bgc=[0.3,0.3,0.3],annotation='Ashi',command=lambda *args:select_icon('Foot'))

    cmds.setParent('..')
    cmds.setParent('..')
    cmds.setParent('..')

    tab_cl5 = cmds.columnLayout(' Tools ',width=400,height=150,adjustableColumn=True)
    cmds.text(label='Tools For ICONs',width=400,bgc=[0.2,0.2,0.2],align='center' )
    cmds.rowColumnLayout(numberOfColumns=4)
    cmds.button(label='Merge Curves',height=35,width=100,bgc=[0.3,0.3,0.3],command=merge_curves_shapes)
    cmds.button(label='Center Pivot',height=35,width=100,bgc=[0.3,0.3,0.3],command=center_pivot)
    cmds.setParent('..')
    cmds.frameLayout(label = 'Mirror   /   Rotate 90')
    cmds.rowLayout(numberOfColumns=7)
    cmds.button('mirror_x',label= 'Mirror X',width=60, command=mirror_x)
    cmds.button('mirror_y',label= 'Mirror Y',width=60, command=mirror_y)
    cmds.button('mirror_z',label= 'Mirror Z',width=60, command=mirror_z)
    cmds.text(label='     ')
    cmds.button('rotate_x',label= 'Rotate X',width=60, command=rotate_x)
    cmds.button('rotate_y',label= 'Rotate Y',width=60, command=rotate_y)
    cmds.button('rotate_z',label= 'Rotate Z',width=60, command=rotate_z)
    cmds.setParent('..')
    cmds.frameLayout(label = 'Set Color')
    cmds.rowLayout(numberOfColumns=4,adjustableColumn=3)
    cmds.colorIndexSliderGrp('icon_color',label='Select Color ',min=0,max=32,value=0,columnWidth3=[77,70,0])
    cmds.intSlider('icon_color_index', min=0, max=31, value=0,width=95, step=1,dragCommand=lambda x:icon_color_index(int(x)) )
    cmds.text(label='  ')
    cmds.button('set_icon_color_selected',label='SetColorToSelected',command=set_icon_color_selected)
    cmds.setParent(top_w)

    cmds.showWindow()

#--------- ICONs ----------
def select_icon(o_icon):
    if o_icon == 'Triangle':
        cmds.curve(name='Triangle',d=1,
            p=[(6.123233995736766e-17, 6.123233995736766e-17, -1.0), (-0.8660254037844387, -3.061616997868381e-17, 0.4999999999999997),
                (0.8660254037844384, -3.061616997868385e-17,0.5000000000000003),(6.718550035012038e-16, 6.123233995736765e-17, -0.9999999999999998)],
            k=[0.0, 1.7320508075688772, 3.4641016151377544, 5.196152422706631])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Square':
        cmds.curve(name='Square',d=1,
            p=[(-0.7071067811865477, 6.123233995736766e-17, -0.7071067811865475), (-0.7071067811865476, 7.498798913309288e-33, 0.7071067811865476),
                (0.7071067811865476, -6.123233995736766e-17, 0.7071067811865476), (0.7071067811865477, -1.4997597826618576e-32, -0.7071067811865475),
                (-0.7071067811865475, 6.123233995736766e-17, -0.7071067811865477)],
            k=[0.0, 1.414213562373095, 2.82842712474619, 4.242640687119285, 5.65685424949238])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Hexagon':
        cmds.curve(name='Hexagon',d=1,
            p=[(6.123233995736766e-17, 6.123233995736766e-17, -1.0), (-0.8660254037844386, 3.0616169978683836e-17, -0.5000000000000001),
                (-0.8660254037844388, -3.061616997868381e-17, 0.4999999999999997), (-4.498103985761725e-16, -6.123233995736766e-17, 1.0), 
                (0.8660254037844384, -3.0616169978683855e-17, 0.5000000000000004), (0.866025403784439, 3.061616997868379e-17, -0.49999999999999933),
                (9.494107596574928e-16, 6.123233995736766e-17, -1.0)],
            k=[0.0, 0.9999999999999999, 1.9999999999999998, 2.9999999999999996, 3.9999999999999996, 4.999999999999999, 5.999999999999999])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Circle':
        mel.eval('CreateNURBSCircle')
        mel.eval('DeleteHistory')
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'CrossCircle':
        cmds.curve(name='CrossCircle',d=1,
            p=[(0.0, 0.0, -1.0), (0.38227190000000005, 0.0, -0.9228749), (0.7070523, 0.0, -0.7070596), (0.922886, 0.0, -0.3822678),
                (0.9999230000000001, 0.0, -2.2235999999999998e-06), (0.922886, 0.0, 0.38227310000000003), (0.7070523, 0.0, 0.7070516),
                (0.38227190000000005, 0.0, 0.9228864), (0.0, 0.0, 0.9999226000000001), (0.0, 0.0, 0.0), (0.0, 0.0, -1.0),
                (-0.38227190000000005, 0.0, -0.9228749), (-0.7070523, 0.0, -0.7070596), (-0.922886, 0.0, -0.3822678),
                (-0.9999230000000001, 0.0, -2.2235999999999998e-06), (0.0, 0.0, 0.0), (0.9999230000000001, 0.0, -2.2235999999999998e-06),
                (0.922886, 0.0, 0.38227310000000003), (0.7070523, 0.0, 0.7070516), (0.38227190000000005, 0.0, 0.9228864),
                (0.0, 0.0, 0.9999226000000001), (-0.38227190000000005, 0.0, 0.9228864), (-0.7070523, 0.0, 0.7070516),
                (-0.922886, 0.0, 0.38227310000000003), (-0.9999230000000001, 0.0, -2.2235999999999998e-06)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 
                12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0, 21.0, 22.0, 23.0, 24.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )


    elif  o_icon == 'Cross':
        cmds.curve(name='Cross',d=1,
            p=[(-0.6400000000000001, -5.684341886080803e-16, -2.560000000000001),(-0.6400000000000001, -1.4210854715202006e-16, -0.6400000000000002),
                (-2.5600000000000005,-1.4210854715202006e-16, -0.6400000000000002),(-2.5600000000000005, 1.4210854715202006e-16, 0.6400000000000002),
                (-0.6400000000000001, 1.4210854715202006e-16, 0.6400000000000002), (-0.6400000000000001, 5.684341886080803e-16, 2.560000000000001),
                (0.6400000000000001, 5.684341886080803e-16, 2.560000000000001), (0.6400000000000001, 1.4210854715202006e-16, 0.6400000000000002),
                (2.5600000000000005, 1.4210854715202006e-16, 0.6400000000000002), (2.5600000000000005, -1.4210854715202006e-16, -0.6400000000000002),
                (0.6400000000000001, -1.4210854715202006e-16, -0.6400000000000002), (0.6400000000000001, -5.684341886080803e-16, -2.560000000000001),
                (-0.6400000000000001, -5.684341886080803e-16, -2.560000000000001)],
            k=[0.0, 4.8, 9.6, 12.8, 17.6, 22.4, 25.6, 30.4, 35.2, 38.4, 43.2, 48.0, 51.2])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Cross2':
        cmds.curve(name='Cross2',d=3,
            p=[(-1.0, 0.0, -1.980995), (-1.001043, 0.0, -1.677469), (-1.003128, 0.0, -1.070416), (-0.987487, 0.0, -0.980789),
                (-2.198299, 0.0, -1.006427), (-2.826509, 0.0, -0.993504), (-3.04627, 0.0, -1.019557), (-2.988412, 0.0, 0.188034),
                (-3.000082, 0.0, 1.002181), (-3.011261, 0.0, 0.998736), (-1.96697, 0.0, 1.002876), (-1.130002, 0.0, 0.989761),
                (-0.965676, 0.0, 1.038082), (-1.007294, 0.0, 2.11675), (-1.005146, 0.0, 2.93084), (-0.97212, 0.0, 3.01815),
                (0.199517, 0.0, 2.99656), (0.8631, 0.0, 2.995612), (1.034915, 0.0, 3.020994), (0.99724, 0.0, 1.872908),
                (0.976125, 0.0, 1.146322), (1.09826, 0.0, 0.960085), (1.988911, 0.0, 1.013338), (2.89251, 0.0, 0.986564),
                (3.031177, 0.0, 1.040408), (2.982782, 0.0, -0.115925), (3.037694, 0.0, -0.849451), (2.866443, 0.0, -1.041555),
                (1.958961, 0.0, -0.984331), (1.043816, 0.0, -1.021122), (0.990379, 0.0, -0.931182), (0.994668, 0.0, -2.002289),
                (1.03095, 0.0, -2.955363), (0.881531, 0.0, -3.013146), (-0.0505929, 0.0, -2.992053), (-0.834631, 0.0, -3.018641),
                (-1.041342, 0.0, -2.933382), (-1.013781, 0.0, -2.298458), (-1.0, 0.0, -1.980995)],
            k=[0.0, 0.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0,
                18.0, 19.0, 20.0, 21.0, 22.0, 23.0, 24.0, 25.0, 26.0, 27.0, 28.0, 29.0, 30.0, 31.0, 32.0, 33.0, 34.0, 35.0, 36.0, 36.0, 36.0])

        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'FlatCross':
        cmds.curve(name='FlatCross',d=1,
            p=[(-1.3317751530030857, 0.0, -1.3317751530030857), (-1.3317751530030857, 0.0, -1.9976627295046285),
                (1.3317751530030857, 0.0, -1.9976627295046285), (1.3317751530030857, 0.0, -1.3317751530030857),
                (1.9976627295046285, 0.0, -1.3317751530030857),(1.9976627295046285, 0.0, 1.3317751530030857),
                (1.3317751530030857, 0.0, 1.3317751530030857), (1.3317751530030857, 0.0, 1.9976627295046285),
                (-1.3317751530030857, 0.0, 1.9976627295046285), (-1.3317751530030857, 0.0, 1.3317751530030857),
                (-1.9976627295046285, 0.0, 1.3317751530030857),(-1.9976627295046285, 0.0, -1.3317751530030857),
                (-1.3317751530030857, 0.0, -1.3317751530030857)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Angle':
        cmds.curve(name='Angle',d=1,
            p=[(0.0, 0.0, -1.0), (1.0, 0.0, -1.0), (1.0, 0.0, 1.0), (-1.0, 0.0, 1.0), (-1.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, -1.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Star':
        cmds.curve(name='Star',d=1,
            p=[(0.0, 0.0, -2.993802), (-0.886951, 0.0, -0.993802), (-3.0, 0.0, -0.993802), (-1.271527, 0.0, 0.388976), (-2.0, 0.0, 3.006198),
                (-0.0221259, 0.0, 1.423899), (2.0, 0.0, 3.006198), (1.250591, 0.0, 0.383265), (3.0, 0.0, -0.993802), (0.894704, 0.0, -0.993802),
                (0.0, 0.0, -2.993802)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'PoleSquare':
        cmds.curve(name='PoleSquare',d=1,
            p=[(0.0, 0.0, 0.0), (-2.761013168273541e-31, 5.6, -1.2434497875801752e-15), (-0.7, 5.6, -1.0880185641326533e-15),
                (-0.7, 7.0, -1.3988810110276972e-15), (0.7, 7.0, -1.7097434579227411e-15), (0.7, 5.6, -1.3988810110276972e-15),
                (-2.761013168273541e-31, 5.6, -1.2434497875801752e-15)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0])

    elif  o_icon == 'PoleCircle':
        cmds.curve(name='PoleCircle',d=1,
            p=[(0.0, 0.0, 0.0), (6.858022075225179e-16, 5.6000000000000005, 0.0), (0.20683760000000073, 5.6279536000000006, 0.0),
                (0.39966240000000075, 5.7078256, 0.0), (0.5656896000000007, 5.83431, 0.0), (0.6921750000000008, 6.0003378000000005, 0.0),
                (0.7720456000000009, 6.1931622, 0.0), (0.8000060000000007, 6.400000046126, 0.0), (0.0, 6.4, 0.0),
                (6.858022075225179e-16, 5.6000000000000005, 0.0), (-0.20683759999999932, 5.6279536000000006, 0.0),
                (-0.3996623999999993, 5.7078256000000005, 0.0), (-0.5656895999999992, 5.83431, 0.0), (-0.6921749999999993, 6.0003378000000005, 0.0),
                (-0.7720455999999993, 6.193162200000001, 0.0), (-0.8000059999999993, 6.400000046126, 0.0),
                (-0.7720455999999993, 6.6068376, 0.0), (-0.6921749999999992, 6.7996624, 0.0), (-0.5656895999999991, 6.965689600000001, 0.0),
                (-0.39966239999999914, 7.092175000000001, 0.0), (-0.20683759999999915, 7.172045600000001, 0.0),
                (8.817464301741738e-16, 7.200006000000001, 0.0), (0.20683760000000093, 7.172045600000001, 0.0),
                (0.3996624000000009, 7.092175000000001, 0.0), (0.5656896000000009, 6.965689600000001, 0.0), (0.692175000000001, 6.7996624, 0.0),
                (0.7720456000000009, 6.6068376, 0.0), (0.8000060000000007, 6.400000046126, 0.0), (-0.8000059999999993, 6.400000046126, 0.0),
                (0.0, 6.4, 0.0), (8.817464301741738e-16, 7.200006000000001, 0.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0,
                21.0, 22.0, 23.0, 24.0, 25.0, 26.0, 27.0, 28.0, 29.0, 30.0])

    elif  o_icon == 'Circle180':
        cmds.curve(name='Circle180',d=3,
            p=[(6.123233995736766e-17, 6.123233995736766e-17, -1.0), (0.1300602146774189, 6.123233995736766e-17, -1.0),
                (0.39302781734327535, 5.804408661713561e-17, -0.9479318715820457), (0.7254129114729473, 4.442502059028403e-17, -0.7255156445305612),
                (0.947961223884221,2.4042647892376218e-17, -0.3926462374149942),(1.0260193880578898, -1.0645111903335838e-32, 1.738478704349267e-16),
                (0.9479612238842208, -2.4042647892376237e-17, 0.3926462374149945), (0.7254129114729474, -4.4425020590284054e-17, 0.7255156445305615),
                (0.3930278173432749, -5.80440866171356e-17, 0.9479318715820456), (0.1300602146774186, -6.123233995736766e-17, 1.0),
                (-2.2776579365114115e-16, -6.123233995736766e-17, 1.0)],
            k=[0.0, 0.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 8.0, 8.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Circle270':
        cmds.curve(name='Circle270',d=3,
            p=[(2.220446049250313e-16, 0.0, -1.0000003094489522), (0.19352310519547805, 0.0, -0.9999996023421709),
                (0.5898861545353478, 0.0, -0.8809581757294156), (0.9785346688924722, 0.0, -0.40546280650695926),
                (1.0392518068726173, 0.0, 0.2067085253442636), (0.7491704422789917, 0.0, 0.7491704422789919),
                (0.20670852534426326, 0.0, 1.0392518068726175), (-0.40546280650695954, 0.0, 0.9785346688924721),
                (-0.8809581757294158, 0.0, 0.5898861545353475), (-0.9999996023421711, 0.0, 0.19352310519547772),
                (-1.0000003094489522, 0.0, -2.220446049250313e-16)],
            k=[0.0, 0.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 8.0, 8.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Dumbell':
        cmds.curve(name='Dumbell',d=1,
            p=[(-1.8653967654033277, -0.03931243168320739, 8.729113361740067e-18), (-1.735653984951292, -0.03931243168320746, -0.31322746845102345),
                (-1.4224265165002687, -0.039312431683207485, -0.44297024890305914), (-1.1091990480492453, -0.03931243168320746, -0.31322746845102345),
                (-0.9810072427668652, -0.03931243168320739, -0.003746006681673945), (0.9795412313764239, -0.03931243168320739, 8.729113361740067e-18),
                (1.1091990480492453, -0.03931243168320746, -0.31322746845102345), (1.4224265165002687, -0.039312431683207485, -0.44297024890305914),
                (1.735653984951292, -0.03931243168320746, -0.31322746845102345), (1.8653967654033277, -0.03931243168320739, 8.729113361740067e-18),
                (1.735653984951292, -0.03931243168320732, 0.31322746845102345), (1.4224265165002687, -0.03931243168320729, 0.44297024890305914),
                (1.1091990480492453, -0.03931243168320732, 0.31322746845102345), (0.9795412313764239, -0.03931243168320739, 8.729113361740067e-18),
                (-0.9810072427668652, -0.03931243168320739, -0.003746006681673945), (-1.1091990480492453, -0.03931243168320732, 0.31322746845102345),
                (-1.4224265165002687, -0.03931243168320729, 0.44297024890305914), (-1.735653984951292, -0.03931243168320732, 0.31322746845102345),
                (-1.8653967654033277, -0.03931243168320739, 8.729113361740067e-18)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )



#--- 3D ---
    elif  o_icon == 'Piramid':
        cmds.curve(name='Piramid',d=1,
            p=[(0.0, 2.0, 0.0), (1.0, 0.0, -1.0), (-1.0, 0.0, -1.0), (0.0, 2.0, 0.0), (-1.0, 0.0, 1.0), (1.0, 0.0, 1.0), (0.0, 2.0, 0.0),
                (1.0, 0.0, -1.0), (1.0, 0.0, 1.0), (-1.0, 0.0, 1.0), (-1.0, 0.0, -1.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Piramid2':
        cmds.curve(name='Piramid2',d=1,
            p=[(0.0, 0.353553, 0.0), (-0.707107, -0.353553, 0.0), (0.0, -0.353553, 0.707107), (0.0, 0.353553, 0.0), (0.707107, -0.353553, 0.0),
                (0.0, -0.353553, -0.707107), (0.0, 0.353553, 0.0), (-0.707107, -0.353553, 0.0), (0.0, -0.353553, -0.707107),
                (0.707107, -0.353553, 0.0), (0.0, -0.353553, 0.707107), (-0.707107, -0.353553, 0.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Cube':
        cmds.curve(name='Cube',d=1,
            p=[(-0.5, 0.5, -0.5), (-0.5, 0.5, 0.5), (0.5, 0.5, 0.5), (0.5, 0.5, -0.5), (-0.5, 0.5, -0.5), (-0.5, -0.5, -0.5), (-0.5, -0.5, 0.5),
                (0.5, -0.5, 0.5), (0.5, 0.5, 0.5), (-0.5, 0.5, 0.5), (-0.5, -0.5, 0.5), (-0.5, -0.5, -0.5), (0.5, -0.5, -0.5), (0.5, 0.5, -0.5),
                (0.5, 0.5, 0.5), (0.5, -0.5, 0.5), (0.5, -0.5, -0.5)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Hexagonal':
        cmds.curve(name='Hexagon',d=1,
            p=[(-0.5, 1.0, 0.866025), (0.5, 1.0, 0.866025), (0.5, -1.0, 0.866025), (1.0, -1.0, 0.0), (1.0, 1.0, 0.0), (0.5, 1.0, -0.866025),
                (0.5, -1.0, -0.866025), (-0.5, -1.0, -0.866026), (-0.5, 1.0, -0.866026), (-1.0, 1.0, -1.5885e-07), (-1.0, -1.0, -1.5885e-07),
                (-0.5, -1.0, 0.866025), (-0.5, 1.0, 0.866025), (-1.0, 1.0, -1.5885e-07), (-0.5, 1.0, -0.866026), (0.5, 1.0, -0.866025), 
                (1.0, 1.0, 0.0), (0.5, 1.0, 0.866025), (0.5, -1.0, 0.866025), (-0.5, -1.0, 0.866025), (-1.0, -1.0, -1.5885e-07),
                (-0.5, -1.0, -0.866026), (0.5, -1.0, -0.866025), (1.0, -1.0, 0.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0,
                16.0, 17.0, 18.0, 19.0, 20.0, 21.0, 22.0, 23.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Sphere':
        cmds.curve(name='Sphere',d=1,
            p=[(0.0, 1.0, 0.0), (0.0, 0.92388, 0.382683), (0.0, 0.707107, 0.707107), (0.0, 0.382683, 0.92388), (0.0, 0.0, 1.0),
                (0.0, -0.382683, 0.92388), (0.0, -0.707107, 0.707107), (0.0, -0.92388, 0.382683), (0.0, -1.0, 0.0), (0.0, -0.92388, -0.382683),
                (0.0, -0.707107, -0.707107), (0.0, -0.382683, -0.92388), (0.0, 0.0, -1.0), (0.0, 0.382683, -0.92388), (0.0, 0.707107, -0.707107),
                (0.0, 0.92388, -0.382683), (0.0, 1.0, 0.0), (0.382683, 0.92388, 0.0), (0.707107, 0.707107, 0.0), (0.92388, 0.382683, 0.0),
                (1.0, 0.0, 0.0), (0.92388, -0.382683, 0.0), (0.707107, -0.707107, 0.0), (0.382683, -0.92388, 0.0), (0.0, -1.0, 0.0),
                (-0.382683, -0.92388, 0.0), (-0.707107, -0.707107, 0.0), (-0.92388, -0.382683, 0.0), (-1.0, 0.0, 0.0), (-0.92388, 0.382683, 0.0),
                (-0.707107, 0.707107, 0.0), (-0.382683, 0.92388, 0.0), (0.0, 1.0, 0.0), (0.0, 0.92388, -0.382683), (0.0, 0.707107, -0.707107),
                (0.0, 0.382683, -0.92388), (0.0, 0.0, -1.0), (-0.382683, 0.0, -0.92388), (-0.707107, 0.0, -0.707107), (-0.92388, 0.0, -0.382683),
                (-1.0, 0.0, 0.0), (-0.92388, 0.0, 0.382683), (-0.707107, 0.0, 0.707107), (-0.382683, 0.0, 0.92388), (0.0, 0.0, 1.0),
                (0.382683, 0.0, 0.92388), (0.707107, 0.0, 0.707107), (0.92388, 0.0, 0.382683), (1.0, 0.0, 0.0), (0.92388, 0.0, -0.382683),
                (0.707107, 0.0, -0.707107), (0.382683, 0.0, -0.92388), (0.0, 0.0, -1.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0, 21.0, 22.0,
                23.0, 24.0, 25.0, 26.0, 27.0, 28.0, 29.0, 30.0, 31.0, 32.0, 33.0, 34.0, 35.0, 36.0, 37.0, 38.0, 39.0, 40.0, 41.0, 42.0, 43.0,
                44.0, 45.0, 46.0, 47.0, 48.0, 49.0, 50.0, 51.0, 52.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'HalfSphere':
        cmds.curve(name='HalfSphere',d=1,
            p=[(-0.9855031197383329, 0.0, 1.4303815026309845e-10), (-0.9729271360587279, 0.0, -0.15403607830046498),
                (-0.9362866664175752, 0.0, -0.3041790861172003), (-0.8771417306392981, 0.0, -0.4469675579284557),
                (-0.7968832823604518, 0.0, -0.5790435381234215), (-0.696855852590866, 0.0, -0.696855852590866),
                (-0.5790435381234215, 0.0, -0.7968832823604518), (-0.4469675579284557, 0.0, -0.8771417306392981),
                (-0.3041790861172003, 0.0, -0.9362866664175752), (-0.15403607830046498, 0.0, -0.972927292891926),
                (0.0, 0.0, -0.9855028060719362), (0.0, 0.1540356078008698, -0.972927292891926), (0.0, 0.3041792429503986, -0.9362866664175752),
                (0.0, 0.44696740109525734, -0.8771417306392981), (0.0, 0.5790435381234215, -0.7968832823604518),
                (0.0, 0.696855852590866, -0.696855852590866), (0.0, 0.7968834391936502, -0.5790435381234215),
                (0.0, 0.8771417306392981, -0.4469675579284557), (0.0, 0.9362866664175752, -0.3041790861172003),
                (0.0, 0.9729271360587279, -0.15403607830046498), (0.0, 0.9855031197383329, 0.0), (0.0, 0.9729271360587279, 0.15403607830046498),
                (0.0, 0.9362866664175752, 0.3041790861172003), (0.0, 0.8771417306392981, 0.4469675579284557),
                (0.0, 0.7968834391936502, 0.5790435381234215), (0.0, 0.696855852590866, 0.696855852590866),
                (0.0, 0.5790435381234215, 0.7968832823604518), (0.0, 0.44696740109525734, 0.8771417306392981),
                (0.0, 0.3041792429503986, 0.9362866664175752), (0.0, 0.1540356078008698, 0.972927292891926),
                (0.0, 0.0, 0.9855031197383329), (-0.15403607830046498, 0.0, 0.9729271360587279), (-0.3041790861172003, 0.0, 0.9362866664175752),
                (-0.4469675579284557, 0.0, 0.8771417306392981), (-0.5790435381234215, 0.0, 0.7968832823604518),
                (-0.696855852590866, 0.0, 0.696855852590866), (-0.7968832823604518, 0.0, 0.5790435381234215),
                (-0.8771417306392981, 0.0, 0.4469675579284557), (-0.9362866664175752, 0.0, 0.3041790861172003),
                (-0.9729271360587279, 0.0, 0.15403607830046498), (-0.9855031197383329, 0.0, 1.4303815026309845e-10),
                (-0.972927292891926, 0.1540356078008698, 0.0), (-0.9362866664175752, 0.3041792429503986, 0.0),
                (-0.8771417306392981, 0.44696740109525734, 0.0), (-0.7968832823604518, 0.5790435381234215, 0.0),
                (-0.696855852590866, 0.696855852590866, 0.0), (-0.5790435381234215, 0.7968834391936502, 0.0),
                (-0.4469675579284557, 0.8771417306392981, 0.0), (-0.3041790861172003, 0.9362866664175752, 0.0),
                (-0.15403607830046498, 0.9729271360587279, 0.0), (0.0, 0.9855031197383329, 0.0), (0.15403607830046498, 0.9729271360587279, 0.0),
                (0.3041790861172003, 0.9362866664175752, 0.0), (0.4469675579284557, 0.8771417306392981, 0.0),
                (0.5790435381234215, 0.7968834391936502, 0.0), (0.696855852590866, 0.696855852590866, 0.0),
                (0.7968832823604518, 0.5790435381234215, 0.0),(0.8771417306392981, 0.44696740109525734, 0.0),
                (0.9362866664175752, 0.3041792429503986, 0.0),(0.972927292891926, 0.1540356078008698, 0.0),
                (0.9855031197383329, 0.0, 1.4303893442909043e-10),(0.9729271360587279, 0.0, 0.15403607830046498),
                (0.9362866664175752, 0.0, 0.3041790861172003),(0.8771417306392981, 0.0, 0.4469675579284557),
                (0.7968832823604518, 0.0, 0.5790435381234215),(0.696855852590866, 0.0, 0.696855852590866),
                (0.5790435381234215, 0.0, 0.7968832823604518), (0.4469675579284557, 0.0, 0.8771417306392981),
                (0.3041790861172003, 0.0, 0.9362866664175752), (0.15403607830046498, 0.0, 0.9729271360587279),
                (0.0, 0.0, 0.9855031197383329), (0.15403607830046498, 0.0, 0.9729271360587279), (0.3041790861172003, 0.0, 0.9362866664175752),
                (0.4469675579284557, 0.0, 0.8771417306392981), (0.5790435381234215, 0.0, 0.7968832823604518),
                (0.696855852590866, 0.0, 0.696855852590866),(0.7968832823604518, 0.0, 0.5790435381234215),
                (0.8771417306392981, 0.0, 0.4469675579284557), (0.9362866664175752, 0.0, 0.3041790861172003),
                (0.9729271360587279, 0.0, 0.15403607830046498), (0.9855031197383329, 0.0, 1.4303893442909043e-10),
                (0.9729271360587279, 0.0, -0.15403607830046498), (0.9362866664175752, 0.0, -0.3041790861172003),
                (0.8771417306392981, 0.0, -0.4469675579284557), (0.7968832823604518, 0.0, -0.5790435381234215),
                (0.696855852590866, 0.0, -0.696855852590866),(0.5790435381234215, 0.0, -0.7968832823604518),
                (0.4469675579284557, 0.0, -0.8771417306392981), (0.3041790861172003, 0.0, -0.9362866664175752),
                (0.15403607830046498, 0.0, -0.972927292891926), (0.0, 0.0, -0.9855028060719362)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0,
                20.0, 21.0, 22.0, 23.0, 24.0, 25.0, 26.0, 27.0, 28.0, 29.0, 30.0, 31.0, 32.0, 33.0, 34.0, 35.0, 36.0, 37.0, 38.0,
                39.0, 40.0, 41.0, 42.0, 43.0, 44.0, 45.0, 46.0, 47.0, 48.0, 49.0, 50.0, 51.0, 52.0, 53.0, 54.0, 55.0, 56.0, 57.0,
                58.0, 59.0, 60.0, 61.0, 62.0, 63.0, 64.0, 65.0, 66.0, 67.0, 68.0, 69.0, 70.0, 71.0, 72.0, 73.0, 74.0, 75.0, 76.0,
                77.0, 78.0, 79.0, 80.0, 81.0, 82.0, 83.0, 84.0, 85.0, 86.0, 87.0, 88.0, 89.0, 90.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Octahedron':
        cmds.curve(name='Octahedron',d=1,
            p=[(0.0, 1.0, 0.0), (1.0, 0.0, 0.0), (0.0, 0.0, 1.0), (-1.0, 0.0, 0.0), (0.0, 0.0, -1.0), (0.0, 1.0, 0.0), (0.0, 0.0, 1.0), 
                (0.0, -1.0, 0.0), (0.0, 0.0, -1.0), (1.0, 0.0, 0.0), (0.0, 1.0, 0.0), (-1.0, 0.0, 0.0), (0.0, -1.0, 0.0), (1.0, 0.0, 0.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Null':
        cmds.curve(name='Null',d=1,
            p=[(-1.0, 0.0, 0.0), (1.0, 0.0, 0.0),(0.0, 0.0, 0.0),(0.0, 0.0, 1.0),(0.0, 0.0, -1.0),(0.0, 0.0, 0.0),(0.0, 1.0, 0.0), (0.0, -1.0, 0.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Jack':
        cmds.curve(name='Jack',d=1,
            p=[(0.0, 0.0, 0.0), (0.75, 0.0, 0.0), (1.0, 0.25, 0.0), (1.25, 0.0, 0.0), (1.0, -0.25, 0.0), (0.75, 0.0, 0.0), (1.0, 0.0, 0.25),
                (1.25, 0.0, 0.0), (1.0, 0.0, -0.25), (1.0, 0.25, 0.0), (1.0, 0.0, 0.25), (1.0, -0.25, 0.0), (1.0, 0.0, -0.25), (0.75, 0.0, 0.0),
                (0.0, 0.0, 0.0), (-0.75, 0.0, 0.0), (-1.0, 0.25, 0.0), (-1.25, 0.0, 0.0), (-1.0, -0.25, 0.0), (-0.75, 0.0, 0.0), (-1.0, 0.0, 0.25),
                (-1.25, 0.0, 0.0),(-1.0, 0.0, -0.25),(-1.0, 0.25, 0.0), (-1.0, 0.0, 0.25), (-1.0, -0.25, 0.0), (-1.0, 0.0, -0.25), (-0.75, 0.0, 0.0),
                (0.0, 0.0, 0.0), (0.0, 0.75, 0.0), (0.0, 1.0, -0.25), (0.0, 1.25, 0.0), (0.0, 1.0, 0.25), (0.0, 0.75, 0.0), (-0.25, 1.0, 0.0),
                (0.0, 1.25, 0.0), (0.25, 1.0, 0.0), (0.0, 1.0, 0.25), (-0.25, 1.0, 0.0), (0.0, 1.0, -0.25), (0.25, 1.0, 0.0), (0.0, 0.75, 0.0),
                (0.0, 0.0, 0.0), (0.0, -0.75, 0.0), (0.0, -1.0, -0.25), (0.0, -1.25, 0.0), (0.0, -1.0, 0.25), (0.0, -0.75, 0.0), (-0.25, -1.0, 0.0),
                (0.0, -1.25, 0.0),(0.25, -1.0, 0.0), (0.0, -1.0, -0.25), (-0.25, -1.0, 0.0), (0.0, -1.0, 0.25), (0.25, -1.0, 0.0), (0.0, -0.75, 0.0),
                (0.0, 0.0, 0.0), (0.0, 0.0, -0.75), (0.0, 0.25, -1.0), (0.0, 0.0, -1.25), (0.0, -0.25, -1.0), (0.0, 0.0, -0.75),
                (-0.25, 0.0, -1.0), (0.0, 0.0, -1.25),(0.25, 0.0, -1.0),(0.0, 0.25, -1.0), (-0.25, 0.0, -1.0), (0.0, -0.25, -1.0), (0.25, 0.0, -1.0),
                (0.0, 0.0, -0.75), (0.0, 0.0, 0.0), (0.0, 0.0, 0.75), (0.0, 0.25, 1.0), (0.0, 0.0, 1.25), (0.0, -0.25, 1.0), (0.0, 0.0, 0.75),
                (-0.25, 0.0, 1.0), (0.0, 0.0, 1.25), (0.25, 0.0, 1.0), (0.0, 0.25, 1.0), (-0.25, 0.0, 1.0), (0.0, -0.25, 1.0), (0.25, 0.0, 1.0),
                (0.0, 0.0, 0.75)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0, 21.0, 22.0,
                23.0, 24.0, 25.0, 26.0, 27.0, 28.0, 29.0, 30.0, 31.0, 32.0, 33.0, 34.0, 35.0, 36.0, 37.0, 38.0, 39.0, 40.0, 41.0, 42.0, 43.0,
                44.0, 45.0, 46.0, 47.0, 48.0, 49.0, 50.0, 51.0, 52.0, 53.0, 54.0, 55.0, 56.0, 57.0, 58.0, 59.0, 60.0, 61.0, 62.0, 63.0, 64.0,
                65.0, 66.0, 67.0, 68.0, 69.0, 70.0, 71.0, 72.0, 73.0, 74.0, 75.0, 76.0, 77.0, 78.0, 79.0, 80.0, 81.0, 82.0, 83.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Triangles':
        cmds.curve(name='Triangles',d=1,
            p=[(-2.0, 0.0, 0.0), (1.0, 0.0, 1.0), (1.0, 0.0, -1.0), (-2.0, 0.0, 0.0), (1.0, 1.0, 0.0), (1.0, 0.0, 0.0), (1.0, -1.0, 0.0),
                (-2.0, 0.0, 0.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )


#--- Arrow ---
    elif  o_icon == 'LineArrow':
        cmds.curve(name='LineArrow',d=1,
            p=[(0.9999999999999998, 4.996003610813203e-16, 3.3306690738754696e-16),
                (-0.9999999999999998, -4.996003610813203e-16, -3.3306690738754696e-16),(4.440892098500626e-16, -1.0, 1.1102230246251563e-16),
                (-0.9999999999999998, -4.996003610813203e-16, -3.3306690738754696e-16),(-4.440892098500626e-16, 1.0, -1.1102230246251563e-16)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Arrow':
        cmds.curve(name='Arrow',d=1,
            p=[(-1.3199999999999998, -6.594724766273429e-16, -4.39648317751562e-16), (4.39648317751562e-16, -0.99, 1.0991207943789047e-16),
                (1.4654943925052067e-16, -0.33, 3.663735981263016e-17), (0.9899999999999999, -0.3299999999999995, 3.6637359812630164e-16),
                (0.9899999999999997, 0.3300000000000005, 2.930988785010413e-16), (-1.4654943925052067e-16, 0.33, -3.663735981263016e-17),
                (-4.39648317751562e-16, 0.99, -1.0991207943789047e-16), (-1.3199999999999998, -6.594724766273429e-16, -4.39648317751562e-16)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'LineArrows2':
        cmds.curve(name='LineArrows2',d=1,
            p=[(0.9999999999999993, 1.0000000000000004, 2.220446049250313e-16), (1.9999999999999996, 9.992007221626407e-16, 6.661338147750939e-16),
            (1.0000000000000002, -0.9999999999999996, 4.440892098500626e-16), (1.9999999999999996, 9.992007221626407e-16, 6.661338147750939e-16),
            (-1.9999999999999996, -9.992007221626407e-16, -6.661338147750939e-16),(-0.9999999999999993, -1.0000000000000004, -2.220446049250313e-16),
            (-1.9999999999999996, -9.992007221626407e-16, -6.661338147750939e-16),(-1.0000000000000002, 0.9999999999999996, -4.440892098500626e-16)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Arrows2':
        cmds.curve(name='Arrows2',d=1,
            p=[(-2.31, -2.5646151868841117e-16, -5.129230373768223e-16), (-0.9899999999999998, -0.9900000000000001, -1.099120794378905e-16),
                (-0.9899999999999999, -0.3300000000000001, -1.8318679906315082e-16),(0.9900000000000001,-0.3299999999999999, 2.5646151868841117e-16),
                (0.9900000000000002, -0.9899999999999999, 3.2973623831367146e-16), (2.31, 2.5646151868841117e-16, 5.129230373768223e-16),
                (0.9899999999999998, 0.9900000000000001, 1.099120794378905e-16), (0.9899999999999999, 0.3300000000000001, 1.8318679906315082e-16),
                (-0.9900000000000001, 0.3299999999999999, -2.5646151868841117e-16),(-0.9900000000000002,0.9899999999999999, -3.2973623831367146e-16),
                (-2.31, -2.5646151868841117e-16, -5.129230373768223e-16)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'LineArrows4':
        cmds.curve(name='LineArrows4',d=1,
            p=[(1.25, 0.0, -0.5), (1.75, 0.0, 0.0), (1.25, 0.0, 0.5), (1.75, 0.0, 0.0), (-1.75, 0.0, 0.0), (-1.25, 0.0, -0.5), (-1.75, 0.0, 0.0),
                (-1.25, 0.0, 0.5), (-1.75, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 1.75), (-0.5, 0.0, 1.25), (0.0, 0.0, 1.75), (0.5, 0.0, 1.25),
                (0.0, 0.0, 1.75), (0.0, 0.0, -1.75), (0.5, 0.0, -1.25), (0.0, 0.0, -1.75), (-0.5, 0.0, -1.25), (0.0, 0.0, -1.75)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Arrows4':
        cmds.curve(name='Arrows4',d=1,
            p=[(0.0, 0.0, -1.98), (-0.495, 0.0, -1.32), (-0.165, 0.0, -1.32), (-0.165, 0.0, -0.165), (-1.32, 0.0, -0.165), (-1.32, 0.0, -0.495),
                (-1.98, 0.0, 0.0), (-1.32, 0.0, 0.495), (-1.32, 0.0, 0.165), (-0.165, 0.0, 0.165), (-0.165, 0.0, 1.32), (-0.495, 0.0, 1.32),
                (0.0, 0.0, 1.98), (0.495, 0.0, 1.32), (0.165, 0.0, 1.32), (0.165, 0.0, 0.165), (1.32, 0.0, 0.165), (1.32, 0.0, 0.495),
                (1.98, 0.0, 0.0), (1.32, 0.0, -0.495), (1.32, 0.0, -0.165), (0.165, 0.0, -0.165), (0.165, 0.0, -1.32), (0.495, 0.0, -1.32),
                (0.0, 0.0, -1.98)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0,
                19.0, 20.0, 21.0, 22.0, 23.0, 24.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Arrows4s':
        cmds.curve(name='Arrows4s',d=1,
            p=[(0.0, 0.0, -1.1025), (-0.33, 0.0, -0.6075), (-0.165, 0.0, -0.6075), (-0.165, 0.0, -0.165), (-0.6075, 0.0, -0.165),
                (-0.6075, 0.0, -0.33), (-1.1025, 0.0, 0.0), (-0.6075, 0.0, 0.33), (-0.6075, 0.0, 0.165), (-0.165, 0.0, 0.165),
                (-0.165, 0.0, 0.6075), (-0.33, 0.0, 0.6075), (0.0, 0.0, 1.1025), (0.33, 0.0, 0.6075), (0.165, 0.0, 0.6075),
                (0.165, 0.0, 0.165), (0.6075, 0.0, 0.165), (0.6075, 0.0, 0.33), (1.1025, 0.0, 0.0), (0.6075, 0.0, -0.33),
                (0.6075, 0.0, -0.165), (0.165, 0.0, -0.165), (0.165, 0.0, -0.6075), (0.33, 0.0, -0.6075), (0.0, 0.0, -1.1025)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0,
                19.0, 20.0, 21.0, 22.0, 23.0, 24.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Arrows8s':
        cmds.curve(name='Arrows8s',d=1,
            p=[(-1.8975, 0.0, 0.0), (-1.4025, 0.0, 0.37125), (-1.4025, 0.0, 0.12375), (-0.380966, 0.0, 0.157801),(-1.079222, 0.0, 0.904213),
                (-1.254231, 0.0, 0.729204), (-1.341735, 0.0, 1.341735), (-0.729204, 0.0, 1.254231), (-0.904213, 0.0, 1.079222),
                (-0.157801, 0.0, 0.380966), (-0.12375, 0.0, 1.4025), (-0.37125, 0.0, 1.4025), (0.0, 0.0, 1.8975), (0.37125, 0.0, 1.4025),
                (0.12375, 0.0, 1.4025), (0.157801, 0.0, 0.380966), (0.904213, 0.0, 1.079222), (0.729204, 0.0, 1.254231), (1.341735, 0.0, 1.341735),
                (1.254231, 0.0, 0.729204), (1.079222, 0.0, 0.904213), (0.380966, 0.0, 0.157801), (1.4025, 0.0, 0.12375), (1.4025, 0.0, 0.37125),
                (1.8975, 0.0, 0.0), (1.4025, 0.0, -0.37125), (1.4025, 0.0, -0.12375), (0.380966, 0.0, -0.157801), (1.079222, 0.0, -0.904213),
                (1.254231, 0.0, -0.729204), (1.341735, 0.0, -1.341735), (0.729204, 0.0, -1.254231), (0.904213, 0.0, -1.079222),
                (0.157801, 0.0, -0.380966), (0.12375, 0.0, -1.4025), (0.37125, 0.0, -1.4025), (0.0, 0.0, -1.8975), (-0.37125, 0.0, -1.4025),
                (-0.12375, 0.0, -1.4025), (-0.157801, 0.0, -0.380966), (-0.904213, 0.0, -1.079222), (-0.729204, 0.0, -1.254231),
                (-1.341735, 0.0, -1.341735), (-1.254231, 0.0, -0.729204), (-1.079222, 0.0, -0.904213), (-0.380966, 0.0, -0.157801),
                (-1.4025, 0.0, -0.12375), (-1.4025, 0.0, -0.37125), (-1.8975, 0.0, 0.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0,
                19.0, 20.0, 21.0, 22.0, 23.0, 24.0, 25.0, 26.0, 27.0, 28.0, 29.0, 30.0, 31.0, 32.0, 33.0, 34.0, 35.0,
                36.0, 37.0, 38.0, 39.0, 40.0, 41.0, 42.0, 43.0, 44.0, 45.0, 46.0, 47.0, 48.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'RoundArrows':
        cmds.curve(name='RoundArrows',d=1,
            p=[(0.0, 0.003074658631745386, -2.612853), (0.4911402, 0.48687145863174575, -2.5325199),
                (0.9822804, 0.9472148586317457, -2.3634132000000005), (1.4734209, 1.367967558631746, -2.1114609000000013),
                (0.9822804, 1.367967558631746, -2.1114609000000013), (0.4911402, 1.367967558631746, -2.1114609000000013),
                (0.4911402, 1.7343812586317457, -1.785494700000001), (0.4911402, 2.033611758631746, -1.3969410000000009),
                (0.4911402, 2.255169858631746, -0.9594198000000012), (0.48826769999999997, 2.3912897586317463, -0.4911402000000014),
                (0.9594197999999999, 2.2551698586317466, -0.49114020000000136), (1.3969409999999998, 2.0336117586317464, -0.4911402000000012),
                (1.7854946999999999, 1.7343812586317462, -0.491140200000001), (2.1114609, 1.3679675586317466, -0.4911402000000009),
                (2.1114609, 1.367967558631746, -0.9822804000000009), (2.1114609, 1.3679675586317457, -1.4734209000000007),
                (2.3634132, 0.9472148586317461, -0.9822804000000005), (2.5325198999999996, 0.4868714586317464, -0.4911402000000005),
                (2.612853, 0.0030746586317467184, -2.4413191489922434e-16), (2.5325198999999996, 0.48687145863174686, 0.49114019999999947),
                (2.3634132, 0.9472148586317473, 0.9822803999999995), (2.1114609, 1.3679675586317475, 1.4734208999999991),
                (2.1114609, 1.3679675586317472, 0.982280399999999), (2.1114609, 1.3679675586317468, 0.4911401999999991),
                (1.7854946999999999, 1.734381258631747, 0.49114019999999897), (1.3969409999999998, 2.033611758631747, 0.4911401999999988),
                (0.9594197999999999, 2.255169858631747, 0.49114019999999864), (0.48826769999999997, 2.3912897586317468, 0.49114019999999864),
                (0.4911402, 2.255169858631747, 0.9594197999999987), (0.4911402, 2.0336117586317473, 1.3969409999999987),
                (0.4911402, 1.7343812586317475, 1.7854946999999988), (0.4911402, 1.3679675586317475, 2.1114608999999986),
                (0.9822804, 1.3679675586317475, 2.1114608999999986), (1.4734209, 1.3679675586317475, 2.1114608999999986),
                (0.9822804, 0.9472148586317477, 2.363413199999999), (0.4911402, 0.48687145863174774, 2.532519899999999),
                (0.0, 0.0030746586317480507, 2.612853), (-0.4911402, 0.48687145863174774, 2.532519899999999),
                (-0.9822804, 0.9472148586317477, 2.363413199999999), (-1.4734209, 1.3679675586317475, 2.1114608999999986),
                (-0.9822804, 1.3679675586317475, 2.1114608999999986), (-0.4911402, 1.3679675586317475, 2.1114608999999986),
                (-0.4911402, 1.7343812586317475, 1.7854946999999988), (-0.4911402, 2.0336117586317473, 1.3969409999999987),
                (-0.4911402, 2.255169858631747, 0.9594197999999987), (-0.48826769999999997, 2.3912897586317468, 0.49114019999999864),
                (-0.9594197999999999, 2.255169858631747, 0.49114019999999864), (-1.3969409999999998, 2.033611758631747, 0.4911401999999988),
                (-1.7854946999999999, 1.734381258631747, 0.49114019999999897), (-2.1114609, 1.3679675586317468, 0.4911401999999991),
                (-2.1114609, 1.3679675586317472, 0.982280399999999), (-2.1114609, 1.3679675586317475, 1.4734208999999991),
                (-2.3634132, 0.9472148586317473, 0.9822803999999995), (-2.5325198999999996, 0.48687145863174686, 0.49114019999999947),
                (-2.612853, 0.0030746586317467184, -2.4413191489922434e-16), (-2.5325198999999996, 0.4868714586317464, -0.4911402000000005),
                (-2.3634132, 0.9472148586317461, -0.9822804000000005), (-2.1114609, 1.3679675586317457, -1.4734209000000007),
                (-2.1114609, 1.367967558631746, -0.9822804000000009), (-2.1114609, 1.3679675586317466, -0.4911402000000009),
                (-1.7854946999999999, 1.7343812586317462, -0.491140200000001), (-1.3969409999999998, 2.0336117586317464, -0.4911402000000012),
                (-0.9594197999999999, 2.2551698586317466, -0.49114020000000136), (-0.4911402, 2.3912897586317463, -0.48826770000000136),
                (-0.4911402, 2.255169858631746, -0.9594198000000012), (-0.4911402, 2.033611758631746, -1.3969410000000009),
                (-0.4911402, 1.7343812586317457, -1.785494700000001), (-0.4911402, 1.367967558631746, -2.1114609000000013),
                (-0.9822804, 1.367967558631746, -2.1114609000000013), (-1.4734209, 1.367967558631746, -2.1114609000000013),
                (-0.9822804, 0.9472148586317457, -2.3634132000000005), (-0.4911402, 0.48687145863174575, -2.5325199),
                (0.0, 0.003074658631745386, -2.612853)],
            k=[0.0, 2.313563, 4.627126, 6.940689, 8.577823, 10.214958, 11.849695, 13.484432, 15.119169, 16.744737, 18.379474,
                20.014211, 21.648949, 23.283686, 24.92082, 26.557954, 28.871517, 31.18508, 33.498643, 35.812206, 38.12577,
                40.439333, 42.076467, 43.713601, 45.348338, 46.983075, 48.617812, 50.25255, 51.878118, 53.512855, 55.147592,
                56.782329, 58.419463, 60.056598, 62.370161, 64.683724, 66.997287, 69.31085, 71.624413, 73.937976, 75.57511,
                77.212244, 78.846982, 80.481719, 82.116456, 83.742024, 85.376761, 87.011498, 88.646235, 90.280972, 91.918107,
                93.555241, 95.868804, 98.182367, 100.49593, 102.809493, 105.123056, 107.436619, 109.073754, 110.710888, 112.345625,
                113.980362, 115.615099, 117.240667, 118.875404, 120.510142, 122.144879, 123.779616, 125.41675, 127.053884, 129.367447,
                131.68101, 133.994574])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'RoundArrows2':
        cmds.curve(name='RoundArrows2',d=1,
            p=[(-0.5546934922579116, 1.0117634270061684, 2.2546441170238456), (-1.1093869845158233, 1.0117634270061684, 2.2546441170238456),
                (0.0, -0.028036704212408115, 2.6030446004045396), (1.1093869845158233, 1.0117634270061684, 2.2546441170238456),
                (0.5546934922579116, 1.0117634270061684, 2.2546441170238456), (0.5546934922579116, 1.5915218540987381, 1.7730455441235256),
                (0.5546934922579116, 2.114499081856327, 1.074602482382485), (0.5546934922579116, 2.37113301829088, 0.4964436274878571),
                (0.5546934922579116, 2.37113301829088, -0.5030055384600451), (0.5546934922579116, 2.0915641700319387, -1.1153120732830315),
                (0.5546934922579116, 1.5932924357260247, -1.7777629716599561), (0.5571674252333819, 1.0117634270061675, -2.2612060279960327),
                (1.1093869845158233, 1.0117634270061675, -2.2612060279960327), (0.0, -0.028036704212409003, -2.609606511376727),
                (-1.1093869845158233, 1.0117634270061675, -2.2612060279960327), (-0.5546934922579116, 1.0117634270061675, -2.2612060279960327),
                (-0.5546934922579116, 1.613497146181519, -1.7468759946355021), (-0.5546934922579116, 2.074551165930896, -1.1274613773442943),
                (-0.5546934922579116, 2.37113301829088, -0.5030055384600451), (-0.5546934922579116, 2.37113301829088, 0.4964436274878571),
                (-0.5546934922579116, 2.1342029040883124, 1.0302124474014918), (-0.5546934922579116, 1.6316694596813814, 1.723255485298916),
                (-0.5546934922579116, 1.0117634270061684, 2.2546441170238456)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0, 21.0, 22.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )


    elif  o_icon == 'Line90Arrow':
        cmds.curve(name='Line90Arrow',d=1,
            p=[(-1.026019, 0.0, 0.0), (-0.947961, 0.0, 0.392646), (-0.725413, 0.0, 0.725516), (-0.393028, 0.0, 0.947932),
                (-0.13006, 0.0, 1.0), (0.0107043, 0.0, 1.001418), (-0.339542, 0.0, 0.5442), (0.0107043, 0.0, 1.001418), (-0.446514, 0.0, 1.351664)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == '90Arrow':
        cmds.curve(name='90Arrow',d=1,
            p=[(-0.251045, 0.0, 1.015808), (-0.761834, 0.0, 0.979696), (-0.486547, 0.0, 0.930468), (-0.570736, 0.0, 0.886448),
                (-0.72786, 0.0, 0.774834), (-0.909301, 0.0, 0.550655), (-1.023899, 0.0, 0.285854), (-1.063053, 0.0, 9.80765e-09),
                (-0.961797, 0.0, 8.87346e-09), (-0.926399, 0.0, 0.258619), (-0.822676, 0.0, 0.498232), (-0.658578, 0.0, 0.701014),
                (-0.516355, 0.0, 0.802034), (-0.440202, 0.0, 0.841857), (-0.498915, 0.0, 0.567734), (-0.251045, 0.0, 1.015808)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Line180Arrows':
        cmds.curve(name='Line180Arrows',d=1,
            p=[(-0.446514, 0.0, -1.351664), (0.0107043, 0.0, -1.001418), (-0.339542, 0.0, -0.5442), (0.0107043, 0.0, -1.001418),
                (-0.13006, 0.0, -1.0), (-0.393028, 0.0, -0.947932), (-0.725413, 0.0, -0.725516), (-0.947961, 0.0, -0.392646),
                (-1.026019, 0.0, 0.0), (-0.947961, 0.0, 0.392646), (-0.725413, 0.0, 0.725516), (-0.393028, 0.0, 0.947932),
                (-0.13006, 0.0, 1.0), (0.0, 0.0, 1.0), (-0.339542, 0.0, 0.5442), (0.0, 0.0, 1.0), (-0.446514, 0.0, 1.351664)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == '180Arrows':
        cmds.curve(name='180Arrows',d=1,
            p=[(-0.251045, 0.0, -1.015808), (-0.761834, 0.0, -0.979696), (-0.486547, 0.0, -0.930468), (-0.570736, 0.0, -0.886448),
                (-0.72786, 0.0, -0.774834), (-0.909301, 0.0, -0.550655), (-1.023899, 0.0, -0.285854), (-1.063053, 0.0, 9.80765e-09),
                (-1.023899, 0.0, 0.285854), (-0.909301, 0.0, 0.550655), (-0.72786, 0.0, 0.774834), (-0.570736, 0.0, 0.886448),
                (-0.486547, 0.0, 0.930468), (-0.761834, 0.0, 0.979696), (-0.251045, 0.0, 1.015808), (-0.498915, 0.0, 0.567734),
                (-0.440202, 0.0, 0.841857), (-0.516355, 0.0, 0.802034), (-0.658578, 0.0, 0.701014), (-0.822676, 0.0, 0.498232),
                (-0.926399, 0.0, 0.258619), (-0.961797, 0.0, 8.87346e-09), (-0.926399, 0.0, -0.258619), (-0.822676, 0.0, -0.498232),
                (-0.658578, 0.0, -0.701014), (-0.516355, 0.0, -0.802034), (-0.440202, 0.0, -0.841857), (-0.498915, 0.0, -0.567734),
                (-0.251045, 0.0, -1.015808)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0,
                20.0, 21.0, 22.0, 23.0, 24.0, 25.0, 26.0, 27.0, 28.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Line360Arrow':
        cmds.curve(name='Line360Arrow',d=1,
            p=[(-2.12132, 0.0, 2.12132), (-2.427589, 0.0, 1.760219), (-2.671383, 0.0, 1.358164), (-2.852888, 0.0, 0.917653),
                (-2.959949, 0.0, 0.479631), (-2.999992, 0.0, 0.00653153), (-2.964176, 0.0, -0.453565), (-2.839141, 0.0, -0.959046),
                (-2.671717, 0.0, -1.357504), (-2.4336, 0.0, -1.751819), (-2.130993, 0.0, -2.111601), (-1.792857, 0.0, -2.403811),
                (-1.387964, 0.0, -2.656114), (-0.942438, 0.0, -2.844735), (-0.465425, 0.0, -2.962282), (0.00840032, 0.0, -2.999988),
                (0.454939, 0.0, -2.963959), (0.941699, 0.0, -2.844981), (1.349441, 0.0, -2.675776), (1.757329, 0.0, -2.429662),
                (2.128882, 0.0, -2.11373), (2.411311, 0.0, -1.782662), (2.661389, 0.0, -1.377759), (2.847929, 0.0, -0.932812),
                (2.960853, 0.0, -0.474177), (2.999999, 0.0, 0.00169319), (2.964737, 0.0, 0.449986), (2.852196, 0.0, 0.919787),
                (2.675184, 0.0, 1.35062), (2.431628, 0.0, 1.754581), (2.124565, 0.0, 2.11807), (1.773918, 0.0, 2.417691),
                (1.372686, 0.0, 2.663993), (0.923801, 0.0, 2.850887), (0.409006, 0.0, 2.970854), (0.0, 0.0, 3.0), (0.620223, 0.592945, 3.0),
                (-1.0, 0.0, 3.0), (0.620223, -0.592945, 3.0), (0.0, 0.0, 3.0), (0.620223, 0.0, 2.407055), (-1.0, 0.0, 3.0),
                (0.620223, 0.0, 3.592945), (0.0, 0.0, 3.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0,
                21.0, 22.0, 23.0, 24.0, 25.0, 26.0, 27.0, 28.0, 29.0, 30.0, 31.0, 32.0, 33.0, 34.0, 35.0, 36.0, 37.0, 38.0, 39.0,
                40.0, 41.0, 42.0, 43.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'OverArrows':
        cmds.curve(name='OverArrows',d=1,
            p=[(-3.972325078380167, 1.241505559495406, -2.756696114703874e-16), (-2.9915446383506463, 2.5597753382632042, 0.23863999999999944),
                (-2.65405600671915, 2.222286706631708, 0.2386399999999995), (-3.972325078380167, 1.241505559495406, -2.756696114703874e-16),
                (-2.65405600671915, 2.222286706631708, 0.2386399999999995), (-2.65405600671915, 2.222286706631708, -0.2386400000000005),
                (-3.972325078380167, 1.241505559495406, -2.756696114703874e-16), (-2.65405600671915, 2.222286706631708, -0.2386400000000005),
                (-2.9915446383506463, 2.5597753382632042, -0.23864000000000055), (-3.972325078380167, 1.241505559495406, -2.756696114703874e-16),
                (-2.9915446383506463, 2.5597753382632042, 0.23863999999999944), (-2.9915446383506463, 2.5597753382632042, -0.23864000000000055),
                (-3.972325078380167, 1.241505559495406, -2.756696114703874e-16), (-2.6069153189377863, 2.6069153189377867, -5.788514820665528e-16),
                (-1.9614611780028937, 3.1216480434482845, -6.931451065224713e-16), (-1.217651312232077, 3.4798485398075156, -7.726815942205069e-16),
                (-0.4127834830125834, 3.663554174453, -8.134724392878656e-16), (0.41278348301258405, 3.6635541744529996, -8.134724392878655e-16),
                (1.2176513122320776, 3.4798485398075156, -7.726815942205069e-16), (1.961461178002894, 3.121648043448284, -6.931451065224712e-16),
                (2.6069153189377867, 2.6069153189377863, -5.788514820665527e-16), (3.9723250783801674, 1.2415055594954054, -2.7566961147038725e-16),
                (2.65405600671915, 2.222286706631707, 0.2386399999999995), (2.9915446383506463, 2.5597753382632034, 0.23863999999999944),
                (3.9723250783801674, 1.2415055594954054, -2.7566961147038725e-16), (2.9915446383506463, 2.5597753382632034, 0.23863999999999944),
                (2.9915446383506463, 2.5597753382632034, -0.23864000000000055), (3.9723250783801674, 1.2415055594954054, -2.7566961147038725e-16),
                (2.65405600671915, 2.222286706631707, -0.2386400000000005), (2.9915446383506463, 2.5597753382632034, -0.23864000000000055),
                (2.65405600671915, 2.222286706631707, -0.2386400000000005), (2.65405600671915, 2.222286706631707, 0.2386399999999995)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0, 21.0, 22.0,
                23.0, 24.0, 25.0, 26.0, 27.0, 28.0, 29.0, 30.0, 31.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'BothArrows':
        cmds.curve(name='BothArrows',d=1,
            p=[(-2.187163, -0.5, -0.5), (-2.187163, -0.5, 0.5), (-2.187163, 0.5, 0.5), (-2.187163, 0.5, -0.5), (-2.187163, -0.5, -0.5),
                (-3.812837, 0.0, 0.0), (-2.187163, -0.5, 0.5), (-2.187163, 0.5, 0.5), (-3.812837, 0.0, 0.0), (-2.187163, 0.5, -0.5),
                (-3.812837, 0.0, 0.0),(0.0, 0.0, 0.0), (3.812837, 0.0, 0.0), (2.187163, 0.5, 0.5), (2.187163, 0.5, -0.5), (3.812837, 0.0, 0.0),
                (2.187163, 0.5, -0.5), (2.187163, -0.5, -0.5), (3.812837, 0.0, 0.0), (2.187163, -0.5, -0.5), (2.187163, -0.5, 0.5),
                (3.812837, 0.0, 0.0), (2.187163, -0.5, 0.5), (2.187163, 0.5, 0.5)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0, 21.0, 22.0, 23.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'ArrowDown':
        cmds.curve(name='ArrowDown',d=1,
            p=[(7.882609210987501e-16, 5.599999999999992, 5.854783632927615e-17), (1.9998460000000011, 5.599999999999992, -4.447199999941452e-06),
                (1.8457720000000009, 5.599999999999992, 0.7645462000000002), (1.4141046000000008, 5.599999999999992, 1.4141032),
                (0.7645438000000009, 5.599999999999992, 1.8457728), (7.882609210987501e-16, 5.599999999999992, 1.9998452000000002),
                (7.882609210987501e-16, 5.599999999999992, 5.854783632927615e-17), (7.882609210987501e-16, 5.599999999999992, 1.9998452000000002),
                (-0.7645437999999993, 5.599999999999992, 1.8457728), (-1.414104599999999, 5.599999999999992, 1.4141032),
                (-1.845771999999999, 5.599999999999992, 0.7645462000000002), (-1.9998459999999993, 5.599999999999992, -4.447199999941452e-06),
                (7.882609210987501e-16, 5.599999999999992, 5.854783632927615e-17), (-1.9998459999999993, 5.599999999999992, -4.447199999941452e-06),
                (-1.845771999999999, 5.599999999999992, -0.7645355999999999), (-1.414104599999999, 5.599999999999992, -1.4141192),
                (-0.7645437999999993, 5.599999999999992, -1.8457498), (7.882609210987501e-16, 5.599999999999992, -2.0),
                (7.882609210987501e-16, 5.599999999999992, 5.854783632927615e-17), (7.882609210987501e-16, 5.599999999999992, -2.0),
                (0.7645438000000009, 5.599999999999992, -1.8457498), (1.4141046000000008, 5.599999999999992, -1.4141192),
                (1.8457720000000009, 5.599999999999992, -0.7645355999999999), (1.9998460000000011, 5.599999999999992, -4.447199999941452e-06),
                (7.882609210987501e-16, 5.599999999999992, 5.854783632927615e-17),(2.984022014398088e-16,1.5999999999999917, 5.854783632927615e-17),
                (2.984022014398088e-16,1.5999999999999917, 0.8000000000000002),(1.0245871357623221e-16,-8.881784197001252e-15,5.854783632927615e-17),
                (2.984022014398088e-16, 1.5999999999999917, -0.7999999999999999),(2.984022014398088e-16, 1.5999999999999917, 5.854783632927615e-17), 
                (-0.7999999999999997,1.5999999999999917,5.854783632927615e-17),(1.0245871357623221e-16,-8.881784197001252e-15,5.854783632927615e-17),
                (0.8000000000000004, 1.5999999999999917, 5.854783632927615e-17), (2.984022014398088e-16, 1.5999999999999917, 0.8000000000000002),
                (-0.7999999999999997, 1.5999999999999917, 5.854783632927615e-17), (2.984022014398088e-16, 1.5999999999999917, -0.7999999999999999),
                (0.8000000000000004, 1.5999999999999917, 5.854783632927615e-17), (2.984022014398088e-16, 1.5999999999999917, 5.854783632927615e-17)],
            k=[0.0, 9.99923, 13.898834, 17.798388, 21.697965, 25.597534, 35.59676, 45.595986, 49.495555, 53.395131, 57.294686, 61.19429, 71.19352,
                81.192749, 85.092258, 88.991923, 92.891392, 96.791136, 106.791136, 116.791136, 120.690881, 124.59035, 128.490015, 132.389524,
                142.388753, 162.388753, 166.388753, 175.333025, 184.277297, 188.277297, 192.277297, 201.221569, 210.165841, 215.822695, 221.479549,
                227.136403, 232.793258, 236.793258])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'ArrowDown2':
        cmds.curve(name='ArrowDown2',d=1,
            p=[(0.0, 0.0, 0.0), (-1.9998460000000002, 0.0, -4.4471999999999995e-06), (-1.845772, 0.0, 0.7645462000000001),
                (-1.4141046, 0.0, 1.4141032), (-0.7645438000000001, 0.0, 1.8457728), (0.0, 0.0, 1.9998452000000002), (0.0, 0.0, 0.0),
                (0.0, 0.0, 1.9998452000000002), (0.7645438000000001, 0.0, 1.8457728),(1.4141046, 0.0, 1.4141032),(1.845772, 0.0, 0.7645462000000001),
                (1.9998460000000002, 0.0, -4.4471999999999995e-06), (0.0, 0.0, 0.0), (1.9998460000000002, 0.0, -4.4471999999999995e-06),
                (1.845772, 0.0, -0.7645356), (1.4141046, 0.0, -1.4141192), (0.7645438000000001, 0.0, -1.8457498), (0.0, 0.0, -2.0), (0.0, 0.0, 0.0),
                (0.0, 0.0, -2.0), (-0.7645438000000001, 0.0, -1.8457498), (-1.4141046, 0.0, -1.4141192), (-1.845772, 0.0, -0.7645356),
                (-1.9998460000000002, 0.0, -4.4471999999999995e-06), (0.0, 0.0, 0.0), (0.0, 4.0, 0.0), (0.0, 5.6000000000000005, 0.8),
                (0.0, 5.6000000000000005, 0.0), (0.0, 5.6000000000000005, -0.8), (0.0, 4.0, 0.0), (0.8, 5.6000000000000005, 0.0),
                (0.0, 5.6000000000000005, 0.0), (-0.8, 5.6000000000000005, 0.0), (0.0, 5.6000000000000005, 0.8), (0.8, 5.6000000000000005, 0.0),
                (0.0, 5.6000000000000005, -0.8), (-0.8, 5.6000000000000005, 0.0), (0.0, 4.0, 0.0)],
            k=[0.0, 9.99923, 13.898834, 17.798388, 21.697965, 25.597534, 35.59676, 45.595986, 49.495555, 53.395131, 57.294686, 61.19429, 71.19352,
                81.192749, 85.092258, 88.991923, 92.891392, 96.791136, 106.791136, 116.791136, 120.690881, 124.59035, 128.490015, 132.389524,
                142.388753, 162.388753, 166.388753, 175.333025, 184.277297, 188.277297, 192.277297, 201.221569, 210.165841, 215.822695,
                221.479549, 227.136403, 232.793258, 236.793258])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'ArrowDown3':
        cmds.curve(name='ArrowDown3',d=1,
            p=[(-1.6485242005752952e-16, 1.5999999999999943, 0.0), (0.7999999999999999, 1.5999999999999943, 0.0),
                (-3.60795907921106e-16, -5.329070518200751e-15, 0.0), (-0.8000000000000002, 1.5999999999999943, 0.0),
                (-1.6485242005752952e-16, 1.5999999999999943, 0.0), (3.2500629960141186e-16, 5.599999999999995, 0.0),
                (-0.2068375999999997, 5.627953599999995, 0.0), (-0.3996623999999997, 5.707825599999995, 0.0),
                (-0.5656895999999997, 5.834309999999995, 0.0), (-0.6921749999999997, 6.000337799999995, 0.0),
                (-0.7720455999999997, 6.193162199999995, 0.0), (-0.8000059999999996, 6.400000046125995, 0.0),
                (-0.7720455999999997, 6.606837599999995, 0.0), (-0.6921749999999997, 6.799662399999995, 0.0),
                (-0.5656895999999995, 6.965689599999995, 0.0), (-0.3996623999999995, 7.092174999999995, 0.0),
                (-0.20683759999999954, 7.172045599999995, 0.0), (5.209505222530678e-16, 7.200005999999995, 0.0),
                (0.20683760000000054, 7.172045599999995, 0.0), (0.3996624000000006, 7.092174999999995, 0.0),
                (0.5656896000000006, 6.965689599999995, 0.0), (0.6921750000000005, 6.7996623999999946, 0.0),
                (0.7720456000000006, 6.606837599999995, 0.0), (0.8000060000000004, 6.400000046125995, 0.0),
                (0.7720456000000006, 6.193162199999995, 0.0), (0.6921750000000005, 6.000337799999995, 0.0),
                (0.5656896000000003, 5.834309999999995, 0.0), (0.39966240000000036, 5.707825599999995, 0.0),
                (0.20683760000000037, 5.627953599999995, 0.0), (3.2500629960141186e-16, 5.599999999999995, 0.0)],
            k=[0.0, 4.0, 12.944272, 21.888544, 25.888544, 45.888544, 46.932134, 47.975696, 49.019289, 50.062886, 51.106444, 52.150039,
                53.193634, 54.237194, 55.280789, 56.324384, 57.367943, 58.411538, 59.455133, 60.498693, 61.542288, 62.585882, 63.629442,
                64.673037, 65.716632, 66.760191, 67.803787, 68.84738, 69.890942, 70.934532])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'ArrowDown4':
        cmds.curve(name='ArrowDown4',d=1,
            p=[(0.0, 4.800000000000001, 0.0), (-0.8, 6.4, 0.0), (0.0, 6.4, 0.0), (0.8, 6.4, 0.0), (0.0, 4.800000000000001, 0.0), (0.0, 0.8, 0.0),
                (0.20683760000000004, 0.7720464, 0.0), (0.39966240000000003, 0.6921744000000001, 0.0), (0.5656896, 0.56569, 0.0),
                (0.6921750000000001, 0.3996622, 0.0), (0.7720456000000001, 0.20683780000000002, 0.0), (0.800006, -4.6126e-08, 0.0),
                (0.7720456000000001, -0.20683760000000004, 0.0), (0.6921750000000001, -0.39966240000000003, 0.0), (0.5656896, -0.5656896, 0.0),
                (0.39966240000000003, -0.6921750000000001, 0.0), (0.20683760000000004, -0.7720456000000001, 0.0), (0.0, -0.800006, 0.0),
                (-0.20683760000000004, -0.7720456000000001, 0.0), (-0.39966240000000003, -0.6921750000000001, 0.0), (-0.5656896, -0.5656896, 0.0),
                (-0.6921750000000001, -0.39966240000000003, 0.0), (-0.7720456000000001, -0.20683760000000004, 0.0), (-0.800006, -4.6126e-08, 0.0),
                (-0.7720456000000001, 0.20683780000000002, 0.0), (-0.6921750000000001, 0.3996622, 0.0), (-0.5656896, 0.56569, 0.0),
                (-0.39966240000000003, 0.6921744000000001, 0.0), (-0.20683760000000004, 0.7720464, 0.0), (0.0, 0.8, 0.0)],
            k=[0.0, 4.0, 12.944272, 21.888544, 25.888544, 45.888544, 46.932134, 47.975696, 49.019289, 50.062886, 51.106444, 52.150039, 53.193634,
                54.237194, 55.280789, 56.324384, 57.367943, 58.411538, 59.455133, 60.498693, 61.542288, 62.585882, 63.629442, 64.673037,
                65.716632, 66.760191, 67.803787, 68.84738, 69.890942, 70.934532])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'ArrowDown5':
        cmds.curve(name='ArrowDown5',d=1,
            p=[(0.0, 0.0, 0.0), (5.329070518200752e-16, 2.4000000000000004, -2.4000000000000004), (5.329070518200752e-16, 2.4000000000000004, -1.6),
                (1.0658141036401504e-15, 4.800000000000001, -1.6), (1.0658141036401504e-15, 4.800000000000001, 1.6),
                (5.329070518200752e-16, 2.4000000000000004, 1.6), (5.329070518200752e-16, 2.4000000000000004, 2.4000000000000004), (0.0, 0.0, 0.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == '4SideArrows':
        cmds.curve(name='4SideArrows',d=1,
            p=[(-3.1365431247355415, -3.819023300387824e-17, 0.623693836140637), (-4.0, 0.0, 0.8), (-4.0, 0.0, 1.6), (-5.6000000000000005, 0.0, 0.0),
                (-4.0, 0.0, -1.6), (-4.0, 0.0, -0.8), (-3.1365342751582044, 3.8192692435327155e-17, -0.623734001704301),
                (-2.953211520143946, 7.490485737424009e-17, -1.223289154495677), (-2.6588921488091724, 1.0880178124855442e-16, -1.7768679316241476),
                (-2.2625592428733143, 1.3854423128474127e-16, -2.262599002115569),(-1.776794143541462, 1.6281013397300349e-16, -2.6588912670389244),
                (-1.22321431856483, 1.808320895540634e-16, -2.953212137245867), (-0.6237004032623853, 1.9206572749663177e-16, -3.1366713672930926),
                (-0.8, 0.0, -4.0), (-1.6, 0.0, -4.0), (0.0, 0.0, -5.6000000000000005), (1.6, 0.0, -4.0), (0.8, 0.0, -4.0),
                (0.6237004032623841, 1.9206572749663185e-16, -3.1366713672930926), (1.2232143185648312, 1.808320895540634e-16, -2.9532121372458664),
                (1.776794143541463, 1.6281013397300349e-16, -2.6588912670389258), (2.262559242873315, 1.3854423128474151e-16, -2.2625990021155715),
                (2.6588921488091737, 1.0880178124855452e-16, -1.7768679316241494), (2.953211520143944, 7.49048573742406e-17, -1.223289154495683),
                (3.136534275158203, 3.819269243532748e-17, -0.6237340017043069), (4.0, 0.0, -0.8), (4.0, 0.0, -1.6), (5.6000000000000005, 0.0, 0.0),
                (4.0, 0.0, 1.6), (4.0, 0.0, 0.8), (3.136543124735546, -3.8190233003877864e-17, 0.6236938361406293),
                (2.9532336400027384, -7.490263320801017e-17, 1.2232528311046151), (2.6589082661209607, -1.0879935973282562e-16, 1.7768283852711821),
                (2.2625737811483626, -1.3854177878362525e-16, 2.262558949732831), (1.776844236468518, -1.6281034758848543e-16, 2.658894755644489),
                (1.2232715976872581, -1.8083291678879909e-16, 2.9532256470143374),(0.6237142596966982, -1.9205771067676957e-16, 3.1365404426890713),
                (0.8, 0.0, 4.0), (1.6, 0.0, 4.0), (0.0, 0.0, 5.6000000000000005), (-1.6, 0.0, 4.0), (-0.8, 0.0, 4.0),
                (-0.6237142596966923, -1.920577106767697e-16, 3.136540442689073), (-1.2232715976872506, -1.808329167887991e-16, 2.9532256470143396),
                (-1.7768442364685115, -1.628103475884856e-16, 2.6588947556444924),(-2.2625737811483595, -1.3854177878362547e-16, 2.2625589497328336),
                (-2.6589082661209544, -1.0879935973282614e-16, 1.7768283852711904), (-2.9532336400027375, -7.490263320801076e-17, 1.223252831104622),
                (-3.1365431247355415, -3.819023300387824e-17, 0.623693836140637)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0, 21.0, 22.0, 23.0,
                24.0, 25.0, 26.0, 27.0, 28.0, 29.0, 30.0, 31.0, 32.0, 33.0, 34.0, 35.0, 36.0, 37.0, 38.0, 39.0, 40.0, 41.0, 42.0, 43.0, 44.0, 45.0,
                46.0, 47.0, 48.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == '4SideArrows2':
        cmds.curve(name='4SideArrows2',d=1,
            p=[(-1.009675, 0.0, -0.977991), (-1.009675, 0.0, -3.017713), (-1.009675, 0.0, -3.017713), (-2.0, 0.0, -3.0), (0.0, 0.0, -5.0),
                (2.0, 0.0, -3.0), (1.0, 0.0, -3.0), (1.0, 0.0, -1.0), (3.0, 0.0, -1.0), (3.0, 0.0, -2.0), (5.0, 0.0, 0.0), (3.0, 0.0, 2.0),
                (3.0, 0.0, 1.0), (1.0, 0.0, 1.0), (1.0, 0.0, 3.0), (2.0, 0.0, 3.0), (0.0, 0.0, 5.0), (-2.0, 0.0, 3.0), (-1.0, 0.0, 3.0),
                (-1.0, 0.0, 1.0), (-3.0, 0.0, 1.0), (-3.0, 0.0, 2.0), (-5.0, 0.0, 0.0), (-3.0, 0.0, -2.0), (-3.0, 0.0, -1.0), (-1.0, 0.0, -1.0)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0, 21.0, 22.0, 23.0,
                24.0, 25.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )




#--- Other ---

    elif  o_icon == 'CenterArrows':
        cmds.curve(name='CenterArrows',d=1,
            p=[(0.1058298, 3.38655615, 0.1833027), (-0.10582994999999999, 3.38655615, 0.1833027), (0.0, 4.1625948, 0.0),
                (0.1058298, 3.38655615, 0.1833027), (0.21165975, 3.38655615, 0.0), (0.0, 4.1625948, 0.0), (0.21165975, 3.38655615, 0.0),
                (0.10582994999999999, 3.38655615, -0.1833027), (0.0, 4.1625948, 0.0), (0.10582994999999999, 3.38655615, -0.1833027),
                (-0.1058298, 3.38655615, -0.18330285), (0.0, 4.1625948, 0.0), (-0.1058298, 3.38655615, -0.18330285),
                (-0.21165975, 3.38655615, -3.36222e-08), (0.0, 4.1625948, 0.0), (-0.21165975, 3.38655615, -3.36222e-08),
                (-0.10582994999999999, 3.38655615, 0.1833027), (0.0, 4.1625948, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 4.1625948),
                (-0.1833027, 0.10582994999999999, 3.38655615), (0.0, 0.21165975, 3.38655615), (0.0, 0.0, 4.1625948),
                (0.1833027, 0.1058298, 3.38655615), (0.0, 0.21165975, 3.38655615), (0.1833027, 0.1058298, 3.38655615),
                (0.1833027, -0.10582994999999999, 3.38655615), (0.0, 0.0, 4.1625948), (0.1833027, -0.10582994999999999, 3.38655615),
                (-3.36222e-08, -0.21165975, 3.38655615), (0.0, 0.0, 4.1625948), (-3.36222e-08, -0.21165975, 3.38655615),
                (-0.18330285, -0.1058298, 3.38655615), (0.0, 0.0, 4.1625948), (-0.18330285, -0.1058298, 3.38655615),
                (-0.1833027, 0.10582994999999999, 3.38655615), (0.0, 0.0, 4.1625948), (0.0, 0.0, 0.846639), (0.0, 0.846639, 0.846639),
                (0.0, 0.846639, 0.0), (0.846639, 0.846639, 0.0), (0.846639, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.846639),
                (0.846639, 0.0, 0.846639), (0.846639, 0.0, 0.0), (4.1625948, 0.0, 0.0), (3.38655615, 0.21165975, 0.0),
                (3.38655615, 0.1058298, -0.1833027), (4.1625948, 0.0, 0.0), (3.38655615, 0.1058298, -0.1833027),
                (3.38655615, -0.10582994999999999, -0.1833027), (4.1625948, 0.0, 0.0), (3.38655615, -0.21165975, 3.36222e-08),
                (3.38655615, -0.10582994999999999, -0.1833027), (3.38655615, -0.21165975, 3.36222e-08), (3.38655615, -0.1058298, 0.18330285),
                (4.1625948, 0.0, 0.0), (3.38655615, -0.1058298, 0.18330285), (3.38655615, 0.10582994999999999, 0.1833027),
                (3.38655615, 0.21165975, 0.0), (4.1625948, 0.0, 0.0), (3.38655615, 0.10582994999999999, 0.1833027)],
            k=[0.0, 1.411065, 6.773634, 12.136203, 13.547268, 18.909838, 24.272407, 25.683471, 31.046041, 36.40861, 37.819675, 43.182244, 48.544813,
                49.955878, 55.318448, 60.681017, 62.092082, 67.454651, 95.205283, 122.955915, 128.318484, 129.729549, 135.092118, 140.454687,
                141.865752, 143.276817, 144.687883, 150.050452, 155.413021, 156.824086, 162.186655, 167.549224, 168.96029, 174.322859, 179.685428,
                181.096493, 186.459062, 208.565434, 214.209694, 219.853955, 225.498215, 231.142475, 236.786735, 242.430996, 248.075256, 253.719516,
                275.825888, 281.188457, 282.599522, 287.962091, 293.32466, 294.735726, 300.098295, 305.460864, 306.871929, 308.282994, 309.69406,
                315.056629, 320.419198, 321.830263, 323.241328, 328.603897, 333.966466])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Hand':
        cmds.curve(name='Hand',d=3,
            p=[(-2.58947438077782, 0.7197761434670209, -0.0025129784073583), (-1.7892461093159735, 0.22585102646994515, -0.0025129784073585166),
                (-1.6804196860005327, -0.49509632093022726, -0.0025129784073585413), (-1.1210968272440596, -0.8516781497262639, 0.00251297840735903),
                (-0.2563333465719584, -0.9992926302643447, 0.0025129784073588497), (0.8327133308095016, -1.0062187060598646, 0.00251297840735856),
                (1.0995094383954214, -0.23727766115217297, 0.0025129784073585006), (0.9787909326424771, 0.5570344587265839, 0.0025129784073585253),
                (1.2834535106883505, 1.1278025665351117, -0.002512978407359199), (1.5506174899291634, 2.0399227153380446, -0.0025129784073592587),
                (2.0020418012136716, 2.728176012263527, -0.0025129784073593584), (1.5094807181929537, 2.9855733837727505, -0.002512978407359249),
                (1.4009678553307947, 2.565834288354928, -0.002512978407359225), (0.9859289087278733, 1.850436147719025, -0.002512978407359144),
                (0.7566867969022242, 1.3065269872839296, -0.002512978407359082), (0.7566867969022242, 1.3065269872839296, -0.002512978407359082),
                (1.0957726155680554, 3.0640212974885634, -0.002512978407359157), (1.2816532143322408, 3.3820886561970465, -0.0025129784073591984),
                (0.7634379082375049, 3.5317382907955626, -0.002512978407359084), (0.5928608288230224, 3.1435716426414584, -0.002512978407359064),
                (0.41592070163742745, 2.0562604047693025, -0.0025129784073590062), (0.18982965190248424, 1.4992870210814588, 0.0025129784073587074),
                (0.16928401981962993, 1.4992870210814588, 0.0025129784073587074), (0.19996195505807768, 3.316649197851702, -0.002512978407358958),
                (0.12826408585819116, 3.793597719396481, -0.0025129784073589425), (-0.36821813044542, 3.815393380463263, -0.0025129784073588323),
                (-0.35181241195220037, 2.348233562446253, -0.002512978407358836), (-0.35048035697625085, 1.559220118178162, -0.00251297840735882),
                (-0.47781603951465496, 1.5228776018747299, -0.002512978407358808), (-0.6609004344644542, 3.1620939419702747, -0.002512978407358765),
                (-0.8783873610894894, 3.5032035935516275, -0.002512978407358719), (-1.1990651495145348, 3.211600591277409, -0.0025129784073586476),
                (-1.0370733583884306, 2.202748393932661, -0.002512978407358663), (-0.9873272914685943, 1.2063025366013191, 0.0025129784073589733),
                (-1.0092121886476426, 0.4577995940680497, 0.002512978407358969), (-1.2168112261633466, 0.1605065119483875, -0.002512978407358644),
                (-1.752963708111292, 0.5570959115420506, -0.002512978407358525), (-1.8489894675424685, 0.944535053023733, -0.002512978407358503),
                (-2.537253734609645, 1.1428821364897384, -0.0025129784073583505), (-2.58947438077782, 0.7197761434670209, -0.0025129784073583)],
            k=[0.0, 0.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0,
                20.0, 21.0, 22.0, 23.0, 24.0, 25.0, 26.0, 27.0, 28.0, 29.0, 30.0, 31.0, 32.0, 33.0, 34.0, 35.0, 36.0, 37.0, 37.0, 37.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    elif  o_icon == 'Foot':
        cmds.curve(name='Foot',d=1,
            p=[(0.544891, 0.0, -1.097217), (-0.544891, 0.0, -1.097217), (-0.571904, 0.0, -1.448294), (-0.512279, 0.0, -1.753435),
                (-0.393271, 0.0, -1.92306),(-0.266839, 0.0, -2.035747), (-0.133965, 0.0, -2.097731),(0.0, 0.0, -2.120128),(0.133965, 0.0, -2.097731),
                (0.266839, 0.0, -2.035747),(0.393271, 0.0, -1.92306), (0.512279, 0.0, -1.753435), (0.571904, 0.0, -1.448294),
                (0.544891, 0.0, -1.097217), (0.545054, 0.0, -0.746104),(0.597807, 0.0, -0.419586), (0.673656, 0.0, -0.127237),
                (0.749207, 0.0, 0.167214), (0.824602, 0.0, 0.556128), (0.846144, 0.0, 0.82139),(0.819474, 0.0, 1.166447), (0.737631, 0.0, 1.452029),
                (0.636486, 0.0, 1.679267), (0.519008, 0.0, 1.858641), (0.395504, 0.0, 1.9981),(0.266596, 0.0, 2.09545), (0.134293, 0.0, 2.163449),
                (-1.67422e-06, 0.0, 2.182925), (-0.13416, 0.0, 2.16342), (-0.266779, 0.0, 2.095529),(-0.395472, 0.0, 1.99807),
                (-0.518993, 0.0, 1.858632), (-0.636496, 0.0, 1.679268), (-0.737632, 0.0, 1.452024), (-0.819474, 0.0, 1.166445),
                (-0.846144, 0.0, 0.821387), (-0.824602, 0.0, 0.556128), (-0.749206, 0.0, 0.167213), (-0.673656, 0.0, -0.127237),
                (-0.597808, 0.0, -0.419587),(-0.545054, 0.0, -0.746104), (-0.544891, 0.0, -1.097217)],
            k=[0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0, 21.0,
                22.0, 23.0, 24.0, 25.0, 26.0, 27.0, 28.0, 29.0, 30.0, 31.0, 32.0, 33.0, 34.0, 35.0, 36.0, 37.0, 38.0, 39.0, 40.0, 41.0])
        o_selected = cmds.ls(sl=True)[0]
        o_size = cmds.intSliderGrp('set_size', q=True, value=True)
        cmds.xform(o_selected, scale=(o_size, o_size, o_size) )
        cmds.makeIdentity( apply=True )

    else:
        print('lost list ,' + o_icon)

